@@ -3,6 +3,7 @@ Get information from the user
 """
 
 import collections
+import inspect
 import re
 
 from .. import utils
@@ -348,7 +349,7 @@ class TextFieldJob(JobBase):
     @property
     def text(self):
         """Current text"""
-        return getattr(self, '_text', ())
+        return getattr(self, '_text', '')
 
     @text.setter
     def text(self, text):
@@ -401,21 +402,28 @@ class TextFieldJob(JobBase):
         if self.is_finished:
             return 0
 
-    def initialize(self, *, name, label, text='', validator=None, normalizer=None, obscured=False, read_only=False):
+    def initialize(self, *, name, label, text='', autofinish=False,
+                   validator=None, normalizer=None, obscured=False, read_only=False):
         """
         Set internal state
 
         :param name: Name for internal use
         :param label: Name for user-facing use
-        :param text: Initial text
+        :param text: Initial text or callable (synchronous or asynchronous)
+            which will be called when the job is :meth:`executed
+            <upsies.jobs.base.JobBase.execute>`. The return value is used as the
+            initial text.
+        :param autofinish: Automatically :meth:`finish` after `text` is set
+            successfully
         :param validator: Callable that gets text before job is finished. If
             `ValueError` is raised, it is displayed as a warning instead of
             finishing the job.
+        :type validator: callable or None
         :param normalizer: Callable that gets text and returns the new text. It
             is called before `validator`. It should not raise any exceptions.
-        :param validator: callable or None
+        :type normalizer: callable or None
         :param bool obscured: Whether :attr:`obscured` is set to `True`
-            initially (currently not working)
+            initially (currently fully implemented)
         :param bool read_only: Whether :attr:`read_only` is set to `True`
             initially
         """
@@ -427,10 +435,37 @@ class TextFieldJob(JobBase):
         self.signal.add('is_loading')
         self.signal.add('read_only')
         self.signal.add('obscured')
-        self.text = text
         self.obscured = obscured
         self.read_only = read_only
 
+        if isinstance(text, str):
+            self.text = text
+        else:
+            # Get text from callable when job is executed
+            self._execute_arguments = (text, autofinish)
+
+    def execute(self):
+        text, autofinish = getattr(self, '_execute_arguments', (None, None))
+
+        if inspect.isawaitable(text):
+            self.attach_task(
+                self.fetch_text(coro=text, finish_on_success=autofinish),
+            )
+
+        elif inspect.iscoroutinefunction(text):
+            self.attach_task(
+                self.fetch_text(coro=text(), finish_on_success=autofinish),
+            )
+
+        elif text is not None:
+            if callable(text):
+                self.text = text()
+            else:
+                self.text = text
+
+            if autofinish:
+                self.send(self.text)
+
     def send(self, output):
         """
         Validate `output` before actually sending it
