@@ -40,7 +40,7 @@ class MediainfoJob(JobBase):
 
     def execute(self):
         """Call ``mediainfo`` in an asynchronous thread"""
-        self.add_task(
+        self.attach_task(
             coro=self._get_mediainfo(),
             finish_when_done=True,
         )
