@@ -44,7 +44,7 @@ class SceneSearchJob(JobBase):
 
     def execute(self):
         """Create background search task"""
-        self.add_task(self._search(), finish_when_done=True)
+        self.attach_task(self._search(), finish_when_done=True)
 
     async def _search(self):
         try:
@@ -94,6 +94,11 @@ class SceneCheckJob(JobBase):
         """Final segment of `content_path`"""
         return fs.basename(self._content_path)
 
+    @property
+    def content_stem(self):
+        """Final segment of `content_path` without the file extension"""
+        return fs.strip_extension(fs.basename(self._content_path))
+
     @property
     def is_scene_release(self):
         """
@@ -132,7 +137,7 @@ class SceneCheckJob(JobBase):
     def execute(self):
         """Start asynchronous background worker task"""
         if self._predetermined_result is None:
-            self.add_task(
+            self.attach_task(
                 self._catch_errors(
                     self._verify(),
                 ),
@@ -156,12 +161,16 @@ class SceneCheckJob(JobBase):
 
         else:
             results = await scene.search(self._content_path, only_existing_releases=False)
-            if len(results) >= 2:
+            if self.content_stem in results:
+                # Basename of content_path without extension is existing release
+                await self._verify_release()
+            elif len(results) == 1:
+                # Don't prompt user to pick search result if there is only one
+                await self._verify_release()
+            else:
                 # If there are multiple search results, ask the user which one
                 # `content_path` is supposed to be
                 self.signal.emit('ask_release_name', results)
-            else:
-                await self._verify_release()
 
     def user_selected_release_name(self, release_name):
         """
@@ -173,7 +182,7 @@ class SceneCheckJob(JobBase):
         """
         _log.debug('User selected release name: %r', release_name)
         if release_name:
-            self.add_task(
+            self.attach_task(
                 self._catch_errors(
                     self._verify_release(release_name)
                 )
