@@ -98,7 +98,7 @@ class CreateTorrentJob(base.JobBase):
 
     def execute(self):
         """Get announce URL from `tracker`, then execute torrent creation subprocess"""
-        self._get_announce_url_task = self.add_task(self._get_announce_url())
+        self._get_announce_url_task = self.attach_task(self._get_announce_url())
         self._get_announce_url_task.add_done_callback(
             lambda task: self._start_torrent_creation_process(task.result())
         )
