@@ -7,8 +7,7 @@ subclasses have two main purposes:
 1. Specify jobs that generate metadata, e.g. torrent creation, ``mediainfo``
    output, IMDb ID, etc.
 
-2. Provide coroutine methods, e.g. for :meth:`~.base.TrackerBase.upload`\ ing
-   the generated metadata.
+2. Provide coroutine methods, e.g. for uploading the generated metadata.
 """
 
 from .. import utils
@@ -39,3 +38,8 @@ def tracker(name, **kwargs):
         if cls.name == name:
             return cls(**kwargs)
     raise ValueError(f'Unsupported tracker: {name}')
+
+
+def tracker_names():
+    """Return sequence of valid `name` arguments for :func:`.tracker`"""
+    return sorted(utils.CaseInsensitiveString(cls.name) for cls in trackers())
