@@ -7,9 +7,8 @@ import builtins
 
 import aiobtclientapi
 
-from .. import errors, jobs
-from ..utils import (cached_property, configfiles, fs, imghosts, release,
-                     signal, string, types, webdbs)
+from .. import errors, jobs, utils
+from ..utils import cached_property, release
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -23,23 +22,23 @@ class TrackerConfigBase(dict):
     """
 
     _defaults = {
-        'source': configfiles.config_value(
+        'source': utils.configfiles.config_value(
             value='',
             description='Value of the "source" field in generated torrents.',
         ),
-        'exclude': configfiles.config_value(
+        'exclude': utils.configfiles.config_value(
             value=[],
             description='List of regular expressions. Matching files are excluded from generated torrents.',
         ),
-        'add_to': configfiles.config_value(
-            value=types.Choice(
+        'add_to': utils.configfiles.config_value(
+            value=utils.types.Choice(
                 value='',
                 empty_ok=True,
                 options=aiobtclientapi.client_names(),
             ),
             description=('BitTorrent client to add torrent to after submission.'),
         ),
-        'copy_to': configfiles.config_value(
+        'copy_to': utils.configfiles.config_value(
             value='',
             description='Directory path to copy torrent to after submission.',
         ),
@@ -101,10 +100,8 @@ class TrackerJobsBase(abc.ABC):
     Job instances are provided as :func:`functools.cached_property`, i.e. jobs
     are created only once per session.
 
-    Subclasses that need to run background tasks (e.g. with
-    :func:`asyncio.ensure_future`) should attach a callback to them with
-    :meth:`~.asyncio.Task.add_done_callback` that catches expected exceptions
-    and pass them to :meth:`warn`, :meth:`error` or :meth:`exception`.
+    Subclasses that need to run background tasks should pass them to
+    :meth:`.JobBase.attach_task` or to :meth:`.TrackerBase.attach_task`.
 
     For a description of the arguments see the corresponding properties.
     """
@@ -123,7 +120,7 @@ class TrackerJobsBase(abc.ABC):
         self._exclude_files = exclude_files
         self._common_job_args = common_job_args or {}
         self._options = options or {}
-        self._signal = signal.Signal('warning', 'error', 'exception')
+        self._signal = utils.signal.Signal('warning', 'error', 'exception')
 
     @property
     def content_path(self):
@@ -323,17 +320,17 @@ class TrackerJobsBase(abc.ABC):
     @cached_property
     def imdb(self):
         """:class:`~.webdbs.imdb.ImdbApi` instance"""
-        return webdbs.webdb('imdb')
+        return utils.webdbs.webdb('imdb')
 
     @cached_property
     def tmdb(self):
         """:class:`~.webdbs.tmdb.TmdbApi` instance"""
-        return webdbs.webdb('tmdb')
+        return utils.webdbs.webdb('tmdb')
 
     @cached_property
     def tvmaze(self):
         """:class:`~.webdbs.tvmaze.TvmazeApi` instance"""
-        return webdbs.webdb('tvmaze')
+        return utils.webdbs.webdb('tvmaze')
 
     def get_job_name(self, name):
         """
@@ -378,7 +375,7 @@ class TrackerJobsBase(abc.ABC):
             add_torrent_job = jobs.torrent.AddTorrentJob(
                 autostart=False,
                 client_api=self.bittorrent_client,
-                download_path=fs.dirname(self.content_path),
+                download_path=utils.fs.dirname(self.content_path),
                 check_after_add=self._check_after_add,
                 condition=self.make_job_condition('add_torrent_job'),
                 **self.common_job_args(),
@@ -448,7 +445,16 @@ class TrackerJobsBase(abc.ABC):
             **self.common_job_args(),
         )
 
-    async def _update_release_name_from(self, webdb, webdb_id):
+    async def update_release_name_from(self, webdb, webdb_id):
+        """
+        Update :attr:`release_name_job` with web DB information
+
+        :param webdb: :class:`~.webdbs.base.WebDbApiBase` instance
+        :param webdb_id: ID for `webdb`
+
+        This is a convenience wrapper around :meth:`.ReleaseName.fetch_info` and
+        :meth:`.TextFieldJob.fetch_text`.
+        """
         await self.release_name_job.fetch_text(
             coro=self.release_name.fetch_info(webdb=webdb, webdb_id=webdb_id),
             nonfatal_exceptions=(errors.RequestError,),
@@ -470,12 +476,17 @@ class TrackerJobsBase(abc.ABC):
 
     def _handle_imdb_id(self, imdb_id):
         # Update other webdb queries with IMDb info
-        self.release_name_job.add_task(self._propagate_webdb_info(self.imdb, imdb_id))
+        self.tracker.attach_task(self._propagate_webdb_info(self.imdb, imdb_id))
 
         # Upload poster image from appropriate webdb
         if self._poster_webdb is self.imdb:
             self._start_poster_job(self.imdb, imdb_id)
 
+    @property
+    def imdb_id(self):
+        """IMDb ID if :attr:`imdb_job` is finished or `None`"""
+        return self._get_webdb_id_from_job(self.imdb_job)
+
     @cached_property
     def tmdb_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
@@ -491,11 +502,16 @@ class TrackerJobsBase(abc.ABC):
 
     def _handle_tmdb_id(self, tmdb_id):
         # Update other webdb queries with TMDb info
-        self.release_name_job.add_task(self._propagate_webdb_info(self.tmdb, tmdb_id))
+        self.tracker.attach_task(self._propagate_webdb_info(self.tmdb, tmdb_id))
 
         if self._poster_webdb is self.tmdb:
             self._start_poster_job(self.tmdb, tmdb_id)
 
+    @property
+    def tmdb_id(self):
+        """TMDb ID if :attr:`tmdb_job` is finished or `None`"""
+        return self._get_webdb_id_from_job(self.tmdb_job)
+
     @cached_property
     def tvmaze_job(self):
         """:class:`~.jobs.webdb.WebDbSearchJob` instance"""
@@ -511,14 +527,23 @@ class TrackerJobsBase(abc.ABC):
 
     def _handle_tvmaze_id(self, tvmaze_id):
         # Update other webdb queries with TVmaze info
-        self.release_name_job.add_task(self._propagate_webdb_info(self.tvmaze, tvmaze_id))
+        self.tracker.attach_task(self._propagate_webdb_info(self.tvmaze, tvmaze_id))
 
         if self._poster_webdb is self.tvmaze:
             self._start_poster_job(self.tvmaze, tvmaze_id)
 
+    @property
+    def tvmaze_id(self):
+        """TVmaze ID if :attr:`tvmaze_job` is finished or `None`"""
+        return self._get_webdb_id_from_job(self.tvmaze_job)
+
+    def _get_webdb_id_from_job(self, webdb_job):
+        if webdb_job.is_finished and webdb_job.output:
+            return webdb_job.output[0]
+
     async def _propagate_webdb_info(self, webdb, webdb_id):
         target_webdb_jobs = [
-            j for j in (getattr(self, f'{name}_job') for name in webdbs.webdb_names())
+            j for j in (getattr(self, f'{name}_job') for name in utils.webdbs.webdb_names())
             if (
                 webdb.name not in j.name
                 and j.is_enabled
@@ -526,9 +551,11 @@ class TrackerJobsBase(abc.ABC):
             )
         ]
 
-        query = webdbs.Query(
+        title_english = await webdb.title_english(webdb_id)
+        title_original = await webdb.title_original(webdb_id)
+        query = utils.webdbs.Query(
             type=await webdb.type(webdb_id),
-            title=await webdb.title_original(webdb_id),
+            title=title_english or title_original,
             year=await webdb.year(webdb_id),
         )
 
@@ -536,7 +563,7 @@ class TrackerJobsBase(abc.ABC):
         for job in target_webdb_jobs:
             job.query.update(query)
 
-        await self._update_release_name_from(webdb, webdb_id)
+        await self.update_release_name_from(webdb, webdb_id)
 
     @cached_property
     def screenshots_job(self):
@@ -721,7 +748,8 @@ class TrackerJobsBase(abc.ABC):
 
         :param job: :class:`~.jobs.base.JobBase` instance
         :param slice: :class:`int` to get a specific item from `job`'s output,
-            `None` to return all output as a list or a :class:`slice` object
+            `None` to return all output as a list, or a :class:`slice` object to
+            return only one or more items of the output
         :param default: Default value if `job` is not finished or getting
             `slice` from `job`'s output fails.
 
@@ -783,7 +811,7 @@ class TrackerBase(abc.ABC):
 
     def __init__(self, options=None):
         self._options = options or {}
-        self._signal = signal.Signal('warning', 'error', 'exception')
+        self._signal = utils.signal.Signal('warning', 'error', 'exception')
 
     @property
     @abc.abstractmethod
@@ -809,7 +837,7 @@ class TrackerBase(abc.ABC):
         # "{howto.current}" in `setup_howto_template` with the current section
         # number.
         howto = _Howto(tracker_cls=cls)  # noqa: F841 local variable 'howto' is assigned to but never used
-        return string.evaluate_fstring(cls.setup_howto_template)
+        return utils.string.evaluate_fstring(cls.setup_howto_template)
 
     @property
     def options(self):
@@ -821,6 +849,28 @@ class TrackerBase(abc.ABC):
         """
         return self._options
 
+    @cached_property
+    def _tasks(self):
+        return []
+
+    def attach_task(self, coro, callback=None):
+        """
+        Run awaitable `coro` in background task
+
+        :param coro: Any awaitable
+
+        :param callback: Callable that is called with the return value or
+            exception from `coro`
+        """
+        task = utils.run_task(coro, callback=callback)
+        self._tasks.append(task)
+        return task
+
+    async def await_tasks(self):
+        """Wait for all awaitables passed to :meth:`attach_task`"""
+        for task in self._tasks:
+            await task
+
     @abc.abstractmethod
     async def login(self):
         """Start user session"""
@@ -923,7 +973,7 @@ class _Howto:
             (
                 f'   {self._section}.2 Specify where to host images.\n'
                 f'       $ upsies set trackers.{self._tracker_cls.name}.image_host IMAGE_HOST\n'
-                f'       Supported services: ' + ', '.join(imghosts.imghost_names()) + '\n'
+                f'       Supported services: ' + ', '.join(utils.imghosts.imghost_names()) + '\n'
                 '\n'
                 f'   {self._section}.3 Configure image hosting service.\n'
                 f'       $ upsies upload-images IMAGE_HOST --help\n'
