@@ -179,20 +179,15 @@ class BhdTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def description_job(self):
-        job = jobs.dialog.TextFieldJob(
+        return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
             label='Description',
             condition=self.make_job_condition('description_job'),
+            text=self.generate_description,
+            autofinish=True,
             read_only=True,
             **self.common_job_args(ignore_cache=True),
         )
-        job.add_task(
-            job.fetch_text(
-                coro=self.generate_description(),
-                finish_on_success=True,
-            )
-        )
-        return job
 
     image_host_config = {
         'common': {'thumb_width': 350},
@@ -201,6 +196,7 @@ class BhdTrackerJobs(TrackerJobsBase):
     async def generate_description(self):
         # Wait until all screenshots are uploaded
         await self.upload_screenshots_job.wait()
+
         rows = []
         screenshot_groups = as_groups(
             self.upload_screenshots_job.uploaded_images,
@@ -214,8 +210,10 @@ class BhdTrackerJobs(TrackerJobsBase):
                     if screenshot.thumbnail_url is None:
                         raise RuntimeError(f'No thumbnail for {screenshot}')
                     cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
+
             # Space between columns
             rows.append('   '.join(cells))
+
         screenshots = '[center]\n' + '\n\n'.join(rows) + '\n[/center]'
         promotion = (
             '[align=right][size=1]'
@@ -226,22 +224,17 @@ class BhdTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def tags_job(self):
-        job = jobs.dialog.TextFieldJob(
+        return jobs.dialog.TextFieldJob(
             name=self.get_job_name('tags'),
             label='Tags',
             condition=self.make_job_condition('tags_job'),
+            text=self.generate_tags,
+            autofinish=True,
             read_only=True,
             **self.common_job_args(),
         )
-        job.add_task(
-            job.fetch_text(
-                coro=self.autodetect_tags(),
-                finish_on_success=True,
-            )
-        )
-        return job
 
-    async def autodetect_tags(self):
+    async def generate_tags(self):
         await self.release_name_job.wait()
         await self.scene_check_job.wait()
 
