@@ -2,8 +2,7 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for NBL
 """
 
-import re
-
+from ... import jobs
 from ...utils import cached_property
 from .. import base
 
@@ -23,14 +22,16 @@ class NblTrackerJobs(base.TrackerJobsBase):
 
     @cached_property
     def category_job(self):
-        return self.make_choice_job(
+        return jobs.dialog.ChoiceJob(
             name=self.get_job_name('category'),
             label='Category',
-            autodetected=str(self.release_name.type),
-            options=(
-                {'label': 'Season', 'value': '3', 'regex': re.compile(r'^(?i:season)$')},
-                {'label': 'Episode', 'value': '1', 'regex': re.compile(r'^(?i:episode)$')},
+            condition=self.make_job_condition('category_job'),
+            choices=(
+                ('Season', '3'),
+                ('Episode', '1'),
             ),
+            autodetected=str(self.release_name.type).capitalize(),
+            **self.common_job_args(),
         )
 
     @property
