@@ -159,6 +159,74 @@ class JobWidgetBase(abc.ABC):
                     return True
         return False
 
+    @property
+    def is_focused(self):
+        """Whether this job is currently presented to the user"""
+        return type(self)._focused_job == self.job.name
+
+    _focused_job = None
+
+    def focus_gained(self):
+        """Called by the TUI when this widget is focused"""
+        type(self)._focused_job = self.job.name
+
+    def focus_lost(self):
+        """Called by the TUI when this widget is no longer focused"""
+        type(self)._focused_job = None
+
+    def bind_key(self, *args, **kwargs):
+        """
+        Bind keys globally
+
+        Every widget can have its own :class:`~.KeyBindings` instance, but they
+        won't be honored unless it is focusable and focused.
+
+        This is a decorator that works exactly like prompt-toolkit's
+        :meth:`.KeyBindings.add`.
+
+        All keys are automatically unbound when the job has finished.
+        """
+        # This widget gets key presses if:
+        #
+        # 1. it is marked as focused by the TUI. This should make sure only one
+        #    interactive/focusable widget gets keys at any point.
+        #
+        # 2. no other job is marked as focused. This allows unfocusable widgets
+        #    to get key presses, e.g. CreateTorrentJobWidget doesn't have any
+        #    focusable widgets, but it can cancel the search for a reusable
+        #    torrent on Escape.
+        #
+        # NOTE: The "filter" argument in `kwargs` also determines if a job gets
+        #       key presses.
+        def filter_wrapper(_custom_filter=kwargs.get('filter', None)):
+            if self._focused_job == self.job.name or self._focused_job is None:
+                if _custom_filter is None:
+                    return True
+                elif _custom_filter():
+                    return True
+                else:
+                    return False
+            else:
+                return False
+
+        kwargs['filter'] = Condition(filter_wrapper)
+
+        def decorator(handler):
+            @self._app.key_bindings.add(*args, **kwargs)
+            def key_pressed(event):
+                handler(event)
+
+            def unbind_key(*_, **__):
+                self._app.key_bindings.remove(key_pressed)
+
+            self.job.signal.register('finished', unbind_key)
+
+            # Returning the decorated function allows stacking multiple
+            # @bind_key() decorators
+            return handler
+
+        return decorator
+
     def invalidate(self):
         """Schedule redrawing of the TUI"""
         self._app.invalidate()
