@@ -147,8 +147,19 @@ class DaemonProcess:
 
     def stop(self):
         """Stop the process"""
+        self.send(MsgType.terminate, None)
+
+    def send(self, typ, value):
+        """
+        Send message to process if it is still alive
+
+        If :attr:`is_alive` is `False`, do nothing.
+
+        :param MsgType typ: General message category
+        :param value: Message string, payload, sentinel, etc.
+        """
         if self.is_alive:
-            self._write_queue.put((MsgType.terminate, None))
+            self._write_queue.put((typ, value))
 
     @property
     def is_alive(self):
