@@ -79,7 +79,7 @@ async def get(
 
         * If `cookies` is a :class:`str`, load cookies from that path (if it
           exists), perform the request, and save the new set of cookies to the
-          same path.
+          same path. If this is a relative path, `cache_directory` is prepended.
 
         .. note:: Session cookies are handled separately and automatically.
 
@@ -419,12 +419,12 @@ def clear_session_cookies(domain=None):
 
 
 def _load_permanent_cookies(cookies):
-    if cookies:
-        _log.debug('Loading permanent cookies from %r', cookies)
     if isinstance(cookies, (collections.abc.Mapping, http.cookiejar.CookieJar)):
+        _log.debug('Loading permanent cookies from mapping: %r', cookies)
         return cookies
     elif cookies and isinstance(cookies, (str, pathlib.Path)):
         filepath_abs = os.path.join(_get_cache_directory(), cookies)
+        _log.debug('Loading permanent cookies from file: %r', filepath_abs)
         cookie_jar = http.cookiejar.LWPCookieJar(filepath_abs)
         try:
             cookie_jar.load()
@@ -446,14 +446,15 @@ def _save_permanent_cookies(client, filepath, domain):
     _log.debug('Saving permanent cookies for %r to %r', domain, filepath_abs)
     file_cookie_jar = http.cookiejar.LWPCookieJar(filepath_abs)
     for cookie in client.cookies.jar:
-        if cookie.domain.endswith(domain):
+        if domain.endswith(cookie.domain):
             _log.debug('Saving permanent cookie: %r', cookie)
             file_cookie_jar.set_cookie(cookie)
         else:
-            _log.debug('Ignoring cookie because %r does not end with %r: %r', cookie.domain, domain, cookie)
+            _log.debug('Ignoring cookie because %r does not end with %r: %r', domain, cookie.domain, cookie)
 
     if file_cookie_jar:
         try:
+            utils.fs.mkdir(utils.fs.dirname(filepath_abs))
             file_cookie_jar.save()
         except OSError as e:
             msg = e.strerror if e.strerror else str(e)
