@@ -12,7 +12,7 @@ def imghosts():
     return subclasses(ImageHostBase, submodules(__package__))
 
 
-def imghost(name, options=None):
+def imghost(name, options=None, cache_directory=None):
     """
     Create :class:`.ImageHostBase` instance
 
@@ -21,6 +21,8 @@ def imghost(name, options=None):
         exist in one of this package's submodules.
     :param options: User configuration passed to the subclass specified by
         `name`
+    :param cache_directory: Where to cache URLs of uploaded images or `None` to
+        use :attr:`~upsies.constants.DEFAULT_CACHE_DIRECTORY`.
 
     :raise ValueError: if no matching subclass can be found
 
@@ -28,7 +30,10 @@ def imghost(name, options=None):
     """
     for imghost in imghosts():
         if imghost.name == name:
-            return imghost(options=options)
+            return imghost(
+                options=options,
+                cache_directory=cache_directory,
+            )
     raise ValueError(f'Unsupported image hosting service: {name}')
 
 
