@@ -12,6 +12,7 @@ string.
 
 import asyncio
 import collections
+import functools
 import os
 import re
 import time
@@ -262,15 +263,21 @@ class ReleaseName(collections.abc.Mapping):
         Combination of :attr:`title_with_aka` with :attr:`country` and :attr:`year`
         if appropriate
 
-        If :attr:`year_required` is `True`, :attr:`year` is appended.
+        If :attr:`date` is specified, it is appended to :attr:`title_with_aka`.
+        Otherwise, if :attr:`year_required` is `True`, :attr:`year` is appended.
 
         If :attr:`country_required` is `True`, :attr:`country` is appended.
         """
         title = [self.title_with_aka]
+
+        if self.date:
+            title.append(self.date)
+        elif self.year_required:
+            title.append(self.year)
+
         if self.country_required:
             title.append(self.country)
-        if self.year_required:
-            title.append(self.year)
+
         return ' '.join(title)
 
     @_translated_property
@@ -414,9 +421,12 @@ class ReleaseName(collections.abc.Mapping):
         """
         Date (YYYY-MM-DD)
 
+        Sometimes single episodes are not released as part of a season but with
+        an air date to identify them.
+
         For episodes, this should be the air date or an empty string.
 
-        For anything that isn't an episode, this is an empty string.
+        For anything that isn't an episode, this is always an empty string.
         """
         if self.type is ReleaseType.episode:
             return self._info.get('date') or ''
@@ -711,7 +721,7 @@ class ReleaseName(collections.abc.Mapping):
             self._update_attributes(webdb, webdb_id),
             self._update_type(webdb, webdb_id),
             self._update_country(webdb, webdb_id),
-            self._update_year_country_required(webdb),
+            self._update_year_country_required(webdb, webdb_id),
         )
         _log.debug('Release name updated with %s info: %s', webdb.label, self)
         if callback is not None:
@@ -751,16 +761,16 @@ class ReleaseName(collections.abc.Mapping):
             if countries:
                 self.country = utils.country.tld(countries[0]).upper()
 
-    async def _update_year_country_required(self, webdb):
+    async def _update_year_country_required(self, webdb, webdb_id):
         if self.type in (ReleaseType.season, ReleaseType.episode):
             # Find out if there are any TV show name duplicates. If so, require
             # year and/or country code in release name to pin it down.
 
+            @functools.lru_cache(maxsize=None)
             def normalize_title(title):
                 return unidecode.unidecode(title.casefold())
 
             # Find result with the same title, removing any "smart" matches
-            title_normalized = normalize_title(self.title)
             query = utils.webdbs.Query(title=self.title, type=ReleaseType.series)
             results = [
                 {
@@ -769,44 +779,52 @@ class ReleaseName(collections.abc.Mapping):
                     'countries': await result.countries(),
                 }
                 for result in await webdb.search(query)
-                if title_normalized == normalize_title(result.title)
+                if normalize_title(self.title) == normalize_title(result.title)
             ]
 
-            def has_duplicates(it):
-                tupl = tuple(it)
-                for item in tupl:
-                    if tupl.count(item) > 1:
-                        return True
-                return False
+            # Assemble relevant info
+            info = {
+                'title': normalize_title(self.title),
+                'year': await webdb.year(webdb_id),
+                'countries': await webdb.countries(webdb_id),
+            }
 
-            def make_title(result, country=False, year=False):
-                parts = [result['title']]
-                if country and result['countries']:
-                    parts.append(result['countries'][0])
-                if year and result['year']:
-                    parts.append(result['year'])
-                return parts
+            def has_duplicates(*attributes):
+                combinations = [
+                    combine(result, attributes)
+                    for result in results
+                ]
+                relevant_info = {attr: info[attr] for attr in attributes}
+                return combinations.count(relevant_info) >= 2
 
-            if has_duplicates(make_title(r) for r in results):
-                if not has_duplicates(make_title(r, year=True) for r in results):
+            def combine(result, attributes):
+                combined = {}
+                for attr in attributes:
+                    if result.get(attr):
+                        combined[attr] = result[attr]
+                return combined
+
+            if has_duplicates('title'):
+                if not has_duplicates('title', 'year'):
+                    self.year_required = True
+                elif not has_duplicates('title', 'countries'):
+                    self.country_required = True
+                else:
                     self.year_required = True
-                elif not has_duplicates(make_title(r, country=True) for r in results):
                     self.country_required = True
 
     def format(self, separator=None):
         """Assemble all parts into string"""
         parts = [self.title_with_aka_and_year]
 
-        if self.type in (ReleaseType.season, ReleaseType.episode):
-            if self.date:
-                parts.append(self.date)
-            else:
-                parts.append(str(self.episodes))
+        if self.type in (ReleaseType.season, ReleaseType.episode) and not self.date:
+            parts.append(str(self.episodes))
 
         parts.append(self.resolution)
 
         if self.service:
             parts.append(self.service)
+
         parts.append(self.source)
 
         if self.edition:
@@ -815,10 +833,16 @@ class ReleaseName(collections.abc.Mapping):
         parts.append(self.audio_format)
         if self.audio_channels:
             parts.append(self.audio_channels)
+
         parts.append(self.video_format)
 
         joined = ' '.join(parts) + f'-{self.group}'
-        sep = separator if separator is not None else self._separator
+
+        sep = separator if separator is not None else self.separator
+        if sep == '.':
+            # Remove non-word characters like (e.g.: ,:) with some exceptions
+            joined = re.sub(r'[^ \w\.-]', '', joined)
+
         return joined.replace(' ', sep)
 
 
@@ -919,12 +943,6 @@ class ReleaseInfo(collections.abc.MutableMapping):
     def _guess(self):
         path = self._abspath
 
-        # TODO: Remove when this is fixed upstream:
-        #       https://github.com/guessit-io/guessit/pull/733
-        # guessit doesn't detect AC3 if it's called "AC-3"
-        path = re.sub(rf'({DELIM})(?i:AC-?3)({DELIM})', r'\1AC3\2', path)
-        path = re.sub(rf'({DELIM})(?i:E-?AC-?3)({DELIM})', r'\1EAC3\2', path)
-
         # _log.debug('Running guessit on %r with %r', path, constants.GUESSIT_OPTIONS)
         guess = dict(_guessit.default_api.guessit(path, options=constants.GUESSIT_OPTIONS))
         # _log.debug('Original guess: %r', guess)
