@@ -37,6 +37,7 @@ def _run_mediainfo(video_file_path, *args):
         raise errors.ContentError(e)
 
 
+@functools.lru_cache(maxsize=None)
 def mediainfo(path):
     """
     ``mediainfo`` output as a string
@@ -55,6 +56,7 @@ def mediainfo(path):
     return mi
 
 
+@functools.lru_cache(maxsize=None)
 def duration(path, default=NO_DEFAULT_VALUE):
     """
     Return video duration in seconds (float) or ``0.0`` if it can't be
@@ -98,6 +100,7 @@ def _duration_from_mediainfo(video_file_path):
         raise RuntimeError(f'Unexpected tracks: {tracks!r}')
 
 
+@functools.lru_cache(maxsize=None)
 def tracks(path, default=NO_DEFAULT_VALUE):
     """
     ``mediainfo --Output=JSON`` as dictionary that maps each track's ``@type``
@@ -114,7 +117,6 @@ def tracks(path, default=NO_DEFAULT_VALUE):
         return default
     return _tracks(first_video(path))
 
-@functools.lru_cache(maxsize=None)
 def _tracks(video_file_path):
     stdout = _run_mediainfo(video_file_path, '--Output=JSON')
     tracks = {}
@@ -130,6 +132,7 @@ def _tracks(video_file_path):
         raise RuntimeError(f'{video_file_path}: Unexpected mediainfo output: {stdout}: Missing field: {e}')
 
 
+@functools.lru_cache(maxsize=None)
 def default_track(type, path, default=NO_DEFAULT_VALUE):
     """
     Return default track
@@ -164,6 +167,7 @@ def default_track(type, path, default=NO_DEFAULT_VALUE):
     raise errors.ContentError(f'{path}: No {type.lower()} track found: {all_tracks!r}')
 
 
+@functools.lru_cache(maxsize=None)
 def width(path, default=NO_DEFAULT_VALUE):
     """
     Return displayed width of video file `path`
@@ -197,6 +201,7 @@ def _get_display_width(video_track):
         return int(width)
 
 
+@functools.lru_cache(maxsize=None)
 def height(path, default=NO_DEFAULT_VALUE):
     """
     Return displayed height of video file `path`
@@ -230,6 +235,7 @@ def _get_display_height(video_track):
         return int(height)
 
 
+@functools.lru_cache(maxsize=None)
 def resolution(path, default=NO_DEFAULT_VALUE):
     """
     Return resolution of video file `path` (e.g. "1080p")
@@ -318,6 +324,7 @@ def _get_closest_standard_resolution(video_track):
     return std_resolution
 
 
+@functools.lru_cache(maxsize=None)
 def frame_rate(path, default=NO_DEFAULT_VALUE):
     """
     Return FPS of default video track or ``0.0`` if it can't be determined
@@ -339,6 +346,7 @@ def frame_rate(path, default=NO_DEFAULT_VALUE):
         return 0.0
 
 
+@functools.lru_cache(maxsize=None)
 def bit_depth(path, default=NO_DEFAULT_VALUE):
     """
     Return bit depth of default video track or ``0`` if it can't be determined
@@ -378,6 +386,7 @@ Map HDR format names (e.g. "Dolby Vision") to dictinaries that map mediainfo
 video track fields to regular expressions that must match the fields' values
 """
 
+@functools.lru_cache(maxsize=None)
 def hdr_format(path, default=NO_DEFAULT_VALUE):
     """
     Return HDR format based on `hdr_formats`, e.g. "HDR10", or empty string if
@@ -415,6 +424,7 @@ def hdr_format(path, default=NO_DEFAULT_VALUE):
     return ''
 
 
+@functools.lru_cache(maxsize=None)
 def has_dual_audio(path, default=NO_DEFAULT_VALUE):
     """
     Return `True` if `path` contains multiple audio tracks with different
@@ -443,6 +453,7 @@ def has_dual_audio(path, default=NO_DEFAULT_VALUE):
         return False
 
 
+@functools.lru_cache(maxsize=None)
 def has_commentary(path, default=NO_DEFAULT_VALUE):
     """
     Return `True` if `path` has an audio track with "Commentary"
@@ -472,8 +483,8 @@ _audio_format_translations = (
     # - All identified <format>s are appended (e.g. "TrueHD Atmos").
     # - {<key>: None} means <key> must not exist.
     ('AAC', {'Format': re.compile(r'^AAC$')}),
-    ('AC-3', {'Format': re.compile(r'^AC-3$')}),
-    ('E-AC-3', {'Format': re.compile(r'^E-AC-3$')}),
+    ('DD', {'Format': re.compile(r'^AC-3$')}),
+    ('DDP', {'Format': re.compile(r'^E-AC-3$')}),
     ('TrueHD', {'Format': re.compile(r'MLP ?FBA')}),
     ('TrueHD', {'Format_Commercial_IfAny': re.compile(r'TrueHD')}),
     ('Atmos', {'Format_Commercial_IfAny': re.compile(r'Atmos')}),
@@ -489,6 +500,7 @@ _audio_format_translations = (
     ('Opus', {'Format': re.compile(r'\bOpus\b')}),
 )
 
+@functools.lru_cache(maxsize=None)
 def audio_format(path, default=NO_DEFAULT_VALUE):
     """
     Return audio format (e.g. "AAC", "MP3") or empty string
@@ -544,6 +556,7 @@ _audio_channels_translations = (
     ('7.1', re.compile(r'^10$')),
 )
 
+@functools.lru_cache(maxsize=None)
 def audio_channels(path, default=NO_DEFAULT_VALUE):
     """
     Return audio channels (e.g. "5.1") or empty_string
@@ -580,6 +593,7 @@ _video_translations = (
     ('MPEG-2', {'Format': re.compile(r'^MPEG Video$')}),
 )
 
+@functools.lru_cache(maxsize=None)
 def video_format(path, default=NO_DEFAULT_VALUE):
     """
     Return video format or x264/x265/XviD if they were used or empty string if
@@ -719,6 +733,7 @@ def filter_similar_duration(video_file_paths):
                      if l >= min_duration)
 
 
+@functools.lru_cache(maxsize=None)
 def make_ffmpeg_input(path):
     """
     Make `path` palatable for ffmpeg
