@@ -14,8 +14,8 @@ class WebDbApiBase(abc.ABC):
     """
     Base class for all web DB APIs
 
-    Because not all DBs provide all information, methods that take an `id`
-    argument may raise :class:`NotImplementedError`.
+    Not all DBs provide all information. Methods that take an `id` argument may
+    return an empty string, an empty tuple or `None`.
     """
 
     def __init__(self, config=None):
