@@ -28,7 +28,7 @@ class ImdbApi(WebDbApiBase):
     _url_base = 'https://www.imdb.com'
     _soup_cache = {}
 
-    user_agent = 'Mozilla/5.0 (Windows NT 10.0; rv:107.0) Gecko/20100101 Firefox/107.0'
+    user_agent = 'Mozilla/5.0 (X11; Linux x86_64; rv:107.0) Gecko/20100101 Firefox/107.0'
 
     async def _get_soup(self, path, params={}):
         cache_id = (path, tuple(sorted(params.items())))
