@@ -117,7 +117,7 @@ class TmdbApi(WebDbApiBase):
         return tuple(cast)
 
     async def _countries(self, id):
-        raise NotImplementedError('Country lookup is not implemented for TMDb')
+        return ()
 
     async def creators(self, id):
         creators = []
